        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 28 <strong>control</strong><br>0,1,2,4,5,6,7,8,14,17,22,26,27,29,32,33,34,36,37,38,39,40,42,44,46,47,48,50';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 23 <br>3,9,10,11,12,13,15,16,18,19,20,21,23,24,25,28,30,31,35,41,43,45,49';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 28 <strong>control</strong><br>0,1,2,4,5,6,7,8,14,17,22,26,27,29,32,33,34,36,37,38,39,40,42,44,46,47,48,50';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 23 <br>3,9,10,11,12,13,15,16,18,19,20,21,23,24,25,28,30,31,35,41,43,45,49';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 28 <strong>control</strong><br>0,1,2,4,5,6,7,8,14,17,22,26,27,29,32,33,34,36,37,38,39,40,42,44,46,47,48,50';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 23 <br>3,9,10,11,12,13,15,16,18,19,20,21,23,24,25,28,30,31,35,41,43,45,49';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 28 <strong>control</strong><br>0,1,2,4,5,6,7,8,14,17,22,26,27,29,32,33,34,36,37,38,39,40,42,44,46,47,48,50';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 23 <br>3,9,10,11,12,13,15,16,18,19,20,21,23,24,25,28,30,31,35,41,43,45,49';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 28 <strong>control</strong><br>0,1,2,4,5,6,7,8,14,17,22,26,27,29,32,33,34,36,37,38,39,40,42,44,46,47,48,50';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 23 <br>3,9,10,11,12,13,15,16,18,19,20,21,23,24,25,28,30,31,35,41,43,45,49';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 28 <strong>control</strong><br>0,1,2,4,5,6,7,8,14,17,22,26,27,29,32,33,34,36,37,38,39,40,42,44,46,47,48,50';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 23 <br>3,9,10,11,12,13,15,16,18,19,20,21,23,24,25,28,30,31,35,41,43,45,49';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 28 <strong>control</strong><br>0,1,2,4,5,6,7,8,14,17,22,26,27,29,32,33,34,36,37,38,39,40,42,44,46,47,48,50';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260516 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 23 <br>3,9,10,11,12,13,15,16,18,19,20,21,23,24,25,28,30,31,35,41,43,45,49';}
}
